ocpp/v2_0_1/datatype/charging_profile_criterion

OCPP 2.0.1 ChargingProfileCriterion data type (schema ChargingProfileCriterionType).

to_json/decoder map to/from its OCPP-J JSON object; new (when present) builds a value from the required fields only.

Types

A ChargingProfile consists of ChargingSchedule, describing the amount of power or current that can be delivered per time interval.

FieldTypeReqDescription
charging_limit_sourceList(ChargingLimitSource)For which charging limit sources, charging profiles SHALL be reported. If omitted, the Charging Station SHALL not filter on chargingLimitSource.
charging_profile_idList(Int)List of all the chargingProfileIds requested. Any ChargingProfile that matches one of these profiles will be reported. If omitted, the Charging Station SHALL not filter on chargingProfileId. This field SHALL NOT contain more ids than set in ChargingProfileEntries.maxLimit
charging_profile_purposeChargingProfilePurpose
custom_dataCustomData
stack_levelIntValue determining level in hierarchy stack of profiles. Higher values have precedence over lower values. Lowest level is 0.

Schema: ChargingProfileCriterionType · Charging_Profile · urn:x-oca:ocpp:uid:2:233255

pub type ChargingProfileCriterion {
  ChargingProfileCriterion(
    charging_limit_source: option.Option(
      List(charging_limit_source.ChargingLimitSource),
    ),
    charging_profile_id: option.Option(List(Int)),
    charging_profile_purpose: option.Option(
      charging_profile_purpose.ChargingProfilePurpose,
    ),
    custom_data: option.Option(custom_data.CustomData),
    stack_level: option.Option(Int),
  )
}

Constructors

Values

pub fn decoder() -> decode.Decoder(ChargingProfileCriterion)

Decode a ChargingProfileCriterion from its OCPP-J JSON object, enforcing schema constraints.

pub fn new() -> ChargingProfileCriterion

Construct a ChargingProfileCriterion from its required fields, with every optional field set to None.

pub fn to_json(value: ChargingProfileCriterion) -> json.Json

Encode a ChargingProfileCriterion to its OCPP-J JSON object.

Search Document