ocpp/v2_0_1/enum/certificate_signing_use

OCPP 2.0.1 CertificateSigningUse enumeration (schema CertificateSigningUseEnumType).

to_json/decoder map each constructor to/from its exact schema token.

Types

Indicates the type of the signed certificate that is returned. When omitted the certificate is used for both the 15118 connection (if implemented) and the Charging Station to CSMS connection. This field is required when a typeOfCertificate was included in the SignCertificateRequest that requested this certificate to be signed AND both the 15118 connection and the Charging Station connection are implemented.

pub type CertificateSigningUse {
  ChargingStationCertificate
  V2gCertificate
}

Constructors

  • ChargingStationCertificate
  • V2gCertificate

Values

pub fn decoder() -> decode.Decoder(CertificateSigningUse)

Decode a CertificateSigningUse from its exact schema token.

pub fn to_json(value: CertificateSigningUse) -> json.Json

Encode a CertificateSigningUse to its exact schema token.

Search Document