ocpp/v2_0_1/enum/charging_profile_purpose

OCPP 2.0.1 ChargingProfilePurpose enumeration (schema ChargingProfilePurposeEnumType).

to_json/decoder map each constructor to/from its exact schema token.

Types

Specifies to purpose of the charging profiles that will be cleared, if they meet the other criteria in the request.

Data dictionary: Charging_Profile.Charging_Profile_Purpose.Charging_Profile_Purpose_Code · urn:x-oca:ocpp:uid:1:569231

pub type ChargingProfilePurpose {
  ChargingStationExternalConstraints
  ChargingStationMaxProfile
  TxDefaultProfile
  TxProfile
}

Constructors

  • ChargingStationExternalConstraints
  • ChargingStationMaxProfile
  • TxDefaultProfile
  • TxProfile

Values

pub fn decoder() -> decode.Decoder(ChargingProfilePurpose)

Decode a ChargingProfilePurpose from its exact schema token.

pub fn to_json(value: ChargingProfilePurpose) -> json.Json

Encode a ChargingProfilePurpose to its exact schema token.

Search Document