ocpp/v2_0_1/enum/charging_profile_status

OCPP 2.0.1 ChargingProfileStatus enumeration (schema ChargingProfileStatusEnumType).

to_json/decoder map each constructor to/from its exact schema token.

Types

Returns whether the Charging Station has been able to process the message successfully. This does not guarantee the schedule will be followed to the letter. There might be other constraints the Charging Station may need to take into account.

pub type ChargingProfileStatus {
  Accepted
  Rejected
}

Constructors

  • Accepted
  • Rejected

Values

pub fn decoder() -> decode.Decoder(ChargingProfileStatus)

Decode a ChargingProfileStatus from its exact schema token.

pub fn to_json(value: ChargingProfileStatus) -> json.Json

Encode a ChargingProfileStatus to its exact schema token.

Search Document