ocpp/v2_1/datatype/additional_info

OCPP 2.1 AdditionalInfo data type (schema AdditionalInfoType).

to_json/decoder map to/from its OCPP-J JSON object; new (when present) builds a value from the required fields only.

Types

Contains a case insensitive identifier to use for the authorization and the type of authorization to support multiple forms of identifiers.

FieldTypeReqDescription
additional_id_tokenString(2.1) This field specifies the additional IdToken. (max 255 chars)
custom_dataCustomData
type_StringadditionalInfo can be used to send extra information to CSMS in addition to the regular authorization with IdToken. AdditionalInfo contains one or more custom types, which need to be agreed upon by all parties involved. When the type is not supported, the CSMS/Charging Station MAY ignore the additionalInfo. (max 50 chars)

Schema: AdditionalInfoType

pub type AdditionalInfo {
  AdditionalInfo(
    additional_id_token: String,
    custom_data: option.Option(custom_data.CustomData),
    type_: String,
  )
}

Constructors

Values

pub fn decoder() -> decode.Decoder(AdditionalInfo)

Decode a AdditionalInfo from its OCPP-J JSON object, enforcing schema constraints.

pub fn new(
  additional_id_token additional_id_token: String,
  type_ type_: String,
) -> AdditionalInfo

Construct a AdditionalInfo from its required fields, with every optional field set to None.

pub fn to_json(value: AdditionalInfo) -> json.Json

Encode a AdditionalInfo to its OCPP-J JSON object.

Search Document