ocpp/v2_1/datatype/charging_profile_criterion
OCPP 2.1 ChargingProfileCriterion data type (schema ChargingProfileCriterionType).
to_json/decoder map to/from its OCPP-J JSON object; new (when
present) builds a value from the required fields only.
Types
A ChargingProfileCriterionType is a filter for charging profiles to be selected by a GetChargingProfilesRequest.
| Field | Type | Req | Description |
|---|---|---|---|
charging_limit_source | List(String) | — | For which charging limit sources, charging profiles SHALL be reported. If omitted, the Charging Station SHALL not filter on chargingLimitSource. Values defined in Appendix as ChargingLimitSourceEnumStringType. (max 20 chars) |
charging_profile_id | List(Int) | — | List of all the chargingProfileIds requested. Any ChargingProfile that matches one of these profiles will be reported. If omitted, the Charging Station SHALL not filter on chargingProfileId. This field SHALL NOT contain more ids than set in ChargingProfileEntries.maxLimit |
charging_profile_purpose | ChargingProfilePurpose | — | |
custom_data | CustomData | — | |
stack_level | Int | — | Value determining level in hierarchy stack of profiles. Higher values have precedence over lower values. Lowest level is 0. (≥ 0) |
Schema: ChargingProfileCriterionType
pub type ChargingProfileCriterion {
ChargingProfileCriterion(
charging_limit_source: option.Option(List(String)),
charging_profile_id: option.Option(List(Int)),
charging_profile_purpose: option.Option(
charging_profile_purpose.ChargingProfilePurpose,
),
custom_data: option.Option(custom_data.CustomData),
stack_level: option.Option(Int),
)
}
Constructors
-
ChargingProfileCriterion( charging_limit_source: option.Option(List(String)), charging_profile_id: option.Option(List(Int)), charging_profile_purpose: option.Option( charging_profile_purpose.ChargingProfilePurpose, ), custom_data: option.Option(custom_data.CustomData), stack_level: option.Option(Int), )
Values
pub fn decoder() -> decode.Decoder(ChargingProfileCriterion)
Decode a ChargingProfileCriterion from its OCPP-J JSON object, enforcing schema constraints.
pub fn new() -> ChargingProfileCriterion
Construct a ChargingProfileCriterion from its required fields, with every optional field set to None.
pub fn to_json(value: ChargingProfileCriterion) -> json.Json
Encode a ChargingProfileCriterion to its OCPP-J JSON object.