ocpp/v2_1/datatype/charging_schedule_update

OCPP 2.1 ChargingScheduleUpdate data type (schema ChargingScheduleUpdateType).

to_json/decoder map to/from its OCPP-J JSON object; new (when present) builds a value from the required fields only.

Types

Updates to a ChargingSchedulePeriodType for dynamic charging profiles.

FieldTypeReqDescription
custom_dataCustomData
discharge_limitFloat(2.1) Limit in chargingRateUnit that the EV is allowed to discharge with. Note, these are negative values in order to be consistent with setpoint, which can be positive and negative. + For AC this field represents the sum of all phases, unless values are provided for L2 and L3, in which case this field represents phase L1. (≤ 0.0)
discharge_limit_l2Float(2.1) Limit in chargingRateUnit on phase L2 that the EV is allowed to discharge with. (≤ 0.0)
discharge_limit_l3Float(2.1) Limit in chargingRateUnit on phase L3 that the EV is allowed to discharge with. (≤ 0.0)
limitFloatOptional only when not required by the operationMode, as in CentralSetpoint, ExternalSetpoint, ExternalLimits, LocalFrequency, LocalLoadBalancing. + Charging rate limit during the schedule period, in the applicable chargingRateUnit. This SHOULD be a non-negative value; a negative value is only supported for backwards compatibility with older systems that use a negative value to specify a discharging limit. For AC this field represents the sum of all phases, unless values are provided for L2 and L3, in which case this field represents phase L1.
limit_l2Float(2.1) Charging rate limit on phase L2 in the applicable chargingRateUnit.
limit_l3Float(2.1) Charging rate limit on phase L3 in the applicable chargingRateUnit.
setpointFloat(2.1) Setpoint in chargingRateUnit that the EV should follow as close as possible. Use negative values for discharging. + When a limit and/or dischargeLimit are given the overshoot when following setpoint must remain within these values. This field represents the sum of all phases, unless values are provided for L2 and L3, in which case this field represents phase L1.
setpoint_reactiveFloat(2.1) Setpoint for reactive power (or current) in chargingRateUnit that the EV should follow as closely as possible. Positive values for inductive, negative for capacitive reactive power or current. + This field represents the sum of all phases, unless values are provided for L2 and L3, in which case this field represents phase L1.
setpoint_reactive_l2Float(2.1) Setpoint for reactive power (or current) in chargingRateUnit that the EV should follow on phase L2 as closely as possible.
setpoint_reactive_l3Float(2.1) Setpoint for reactive power (or current) in chargingRateUnit that the EV should follow on phase L3 as closely as possible.
setpoint_l2Float(2.1) Setpoint in chargingRateUnit that the EV should follow on phase L2 as close as possible.
setpoint_l3Float(2.1) Setpoint in chargingRateUnit that the EV should follow on phase L3 as close as possible.

Schema: ChargingScheduleUpdateType

pub type ChargingScheduleUpdate {
  ChargingScheduleUpdate(
    custom_data: option.Option(custom_data.CustomData),
    discharge_limit: option.Option(Float),
    discharge_limit_l2: option.Option(Float),
    discharge_limit_l3: option.Option(Float),
    limit: option.Option(Float),
    limit_l2: option.Option(Float),
    limit_l3: option.Option(Float),
    setpoint: option.Option(Float),
    setpoint_reactive: option.Option(Float),
    setpoint_reactive_l2: option.Option(Float),
    setpoint_reactive_l3: option.Option(Float),
    setpoint_l2: option.Option(Float),
    setpoint_l3: option.Option(Float),
  )
}

Constructors

Values

pub fn decoder() -> decode.Decoder(ChargingScheduleUpdate)

Decode a ChargingScheduleUpdate from its OCPP-J JSON object, enforcing schema constraints.

pub fn new() -> ChargingScheduleUpdate

Construct a ChargingScheduleUpdate from its required fields, with every optional field set to None.

pub fn to_json(value: ChargingScheduleUpdate) -> json.Json

Encode a ChargingScheduleUpdate to its OCPP-J JSON object.

Search Document