ocpp/v2_1/datatype/der_curve
OCPP 2.1 DerCurve data type (schema DERCurveType).
to_json/decoder map to/from its OCPP-J JSON object; new (when
present) builds a value from the required fields only.
Types
| Field | Type | Req | Description |
|---|---|---|---|
curve_data | List(DerCurvePoints) | ✓ | |
custom_data | CustomData | — | |
duration | Float | — | Duration in seconds that this curve will be active. Only absent when default is true. |
hysteresis | Hysteresis | — | |
priority | Int | ✓ | Priority of curve (0=highest) (≥ 0) |
reactive_power_params | ReactivePowerParams | — | |
response_time | Float | — | Open loop response time, the time to ramp up to 90% of the new target in response to the change in voltage, in seconds. A value of 0 is used to mean no limit. When not present, the device should follow its default behavior. |
start_time | DateTime | — | Point in time when this curve will become activated. Only absent when default is true. |
voltage_params | VoltageParams | — | |
y_unit | DerUnit | ✓ |
Schema: DERCurveType
pub type DerCurve {
DerCurve(
curve_data: List(der_curve_points.DerCurvePoints),
custom_data: option.Option(custom_data.CustomData),
duration: option.Option(Float),
hysteresis: option.Option(hysteresis.Hysteresis),
priority: Int,
reactive_power_params: option.Option(
reactive_power_params.ReactivePowerParams,
),
response_time: option.Option(Float),
start_time: option.Option(timestamp.Timestamp),
voltage_params: option.Option(voltage_params.VoltageParams),
y_unit: der_unit.DerUnit,
)
}
Constructors
-
DerCurve( curve_data: List(der_curve_points.DerCurvePoints), custom_data: option.Option(custom_data.CustomData), duration: option.Option(Float), hysteresis: option.Option(hysteresis.Hysteresis), priority: Int, reactive_power_params: option.Option( reactive_power_params.ReactivePowerParams, ), response_time: option.Option(Float), start_time: option.Option(timestamp.Timestamp), voltage_params: option.Option(voltage_params.VoltageParams), y_unit: der_unit.DerUnit, )
Values
pub fn decoder() -> decode.Decoder(DerCurve)
Decode a DerCurve from its OCPP-J JSON object, enforcing schema constraints.
pub fn new(
curve_data curve_data: List(der_curve_points.DerCurvePoints),
priority priority: Int,
y_unit y_unit: der_unit.DerUnit,
) -> DerCurve
Construct a DerCurve from its required fields, with every optional field set to None.