ocpp/v2_1/datatype/ocsp_request_data

OCPP 2.1 OcspRequestData data type (schema OCSPRequestDataType).

to_json/decoder map to/from its OCPP-J JSON object; new (when present) builds a value from the required fields only.

Types

Information about a certificate for an OCSP check.

FieldTypeReqDescription
custom_dataCustomData
hash_algorithmHashAlgorithm
issuer_key_hashStringThe hash of the DER encoded public key: the value (excluding tag and length) of the subject public key field in the issuer’s certificate. (max 128 chars)
issuer_name_hashStringThe hash of the issuer’s distinguished name (DN), that must be calculated over the DER encoding of the issuer’s name field in the certificate being checked. (max 128 chars)
responder_urlStringThis contains the responder URL (Case insensitive). (max 2000 chars)
serial_numberStringThe string representation of the hexadecimal value of the serial number without the prefix “0x” and without leading zeroes. (max 40 chars)

Schema: OCSPRequestDataType

pub type OcspRequestData {
  OcspRequestData(
    custom_data: option.Option(custom_data.CustomData),
    hash_algorithm: hash_algorithm.HashAlgorithm,
    issuer_key_hash: String,
    issuer_name_hash: String,
    responder_url: String,
    serial_number: String,
  )
}

Constructors

Values

pub fn decoder() -> decode.Decoder(OcspRequestData)

Decode a OcspRequestData from its OCPP-J JSON object, enforcing schema constraints.

pub fn new(
  hash_algorithm hash_algorithm: hash_algorithm.HashAlgorithm,
  issuer_key_hash issuer_key_hash: String,
  issuer_name_hash issuer_name_hash: String,
  responder_url responder_url: String,
  serial_number serial_number: String,
) -> OcspRequestData

Construct a OcspRequestData from its required fields, with every optional field set to None.

pub fn to_json(value: OcspRequestData) -> json.Json

Encode a OcspRequestData to its OCPP-J JSON object.

Search Document