ocpp/v2_1/datatype/set_monitoring_data

OCPP 2.1 SetMonitoringData data type (schema SetMonitoringDataType).

to_json/decoder map to/from its OCPP-J JSON object; new (when present) builds a value from the required fields only.

Types

Class to hold parameters of SetVariableMonitoring request.

FieldTypeReqDescription
componentComponent
custom_dataCustomData
idIntAn id SHALL only be given to replace an existing monitor. The Charging Station handles the generation of id’s for new monitors. (≥ 0)
periodic_event_streamPeriodicEventStreamParams
severityIntThe severity that will be assigned to an event that is triggered by this monitor. The severity range is 0-9, with 0 as the highest and 9 as the lowest severity level. The severity levels have the following meaning: + 0-Danger + Indicates lives are potentially in danger. Urgent attention is needed and action should be taken immediately. + 1-Hardware Failure + Indicates that the Charging Station is unable to continue regular operations due to Hardware issues. Action is required. + 2-System Failure + Indicates that the Charging Station is unable to continue regular operations due to software or minor hardware issues. Action is required. + 3-Critical + Indicates a critical error. Action is required. + 4-Error + Indicates a non-urgent error. Action is required. + 5-Alert + Indicates an alert event. Default severity for any type of monitoring event. + 6-Warning + Indicates a warning event. Action may be required. + 7-Notice + Indicates an unusual event. No immediate action is required. + 8-Informational + Indicates a regular operational event. May be used for reporting, measuring throughput, etc. No action is required. + 9-Debug + Indicates information useful to developers for debugging, not useful during operations. (≥ 0)
transactionBoolMonitor only active when a transaction is ongoing on a component relevant to this transaction. Default = false.
type_Monitor
valueFloatValue for threshold or delta monitoring. For Periodic or PeriodicClockAligned this is the interval in seconds.
variableVariable

Schema: SetMonitoringDataType

pub type SetMonitoringData {
  SetMonitoringData(
    component: component.Component,
    custom_data: option.Option(custom_data.CustomData),
    id: option.Option(Int),
    periodic_event_stream: option.Option(
      periodic_event_stream_params.PeriodicEventStreamParams,
    ),
    severity: Int,
    transaction: option.Option(Bool),
    type_: monitor.Monitor,
    value: Float,
    variable: variable.Variable,
  )
}

Constructors

Values

pub fn decoder() -> decode.Decoder(SetMonitoringData)

Decode a SetMonitoringData from its OCPP-J JSON object, enforcing schema constraints.

pub fn new(
  component component: component.Component,
  severity severity: Int,
  type_ type_: monitor.Monitor,
  value value: Float,
  variable variable: variable.Variable,
) -> SetMonitoringData

Construct a SetMonitoringData from its required fields, with every optional field set to None.

pub fn to_json(value: SetMonitoringData) -> json.Json

Encode a SetMonitoringData to its OCPP-J JSON object.

Search Document