ocpp/v2_1/enum/charging_profile_purpose

OCPP 2.1 ChargingProfilePurpose enumeration (schema ChargingProfilePurposeEnumType).

to_json/decoder map each constructor to/from its exact schema token.

Types

Specifies to purpose of the charging profiles that will be cleared, if they meet the other criteria in the request.

pub type ChargingProfilePurpose {
  ChargingStationExternalConstraints
  ChargingStationMaxProfile
  TxDefaultProfile
  TxProfile
  PriorityCharging
  LocalGeneration
}

Constructors

  • ChargingStationExternalConstraints
  • ChargingStationMaxProfile
  • TxDefaultProfile
  • TxProfile
  • PriorityCharging
  • LocalGeneration

Values

pub fn decoder() -> decode.Decoder(ChargingProfilePurpose)

Decode a ChargingProfilePurpose from its exact schema token.

pub fn to_json(value: ChargingProfilePurpose) -> json.Json

Encode a ChargingProfilePurpose to its exact schema token.

Search Document