ocpp/v2_1/enum/control_mode

OCPP 2.1 ControlMode enumeration (schema ControlModeEnumType).

to_json/decoder map each constructor to/from its exact schema token.

Types

(2.1) Indicates whether EV wants to operate in Dynamic or Scheduled mode. When absent, Scheduled mode is assumed for backwards compatibility. + ISO 15118-20: + ServiceSelectionReq(SelectedEnergyTransferService)

pub type ControlMode {
  ScheduledControl
  DynamicControl
}

Constructors

  • ScheduledControl
  • DynamicControl

Values

pub fn decoder() -> decode.Decoder(ControlMode)

Decode a ControlMode from its exact schema token.

pub fn to_json(value: ControlMode) -> json.Json

Encode a ControlMode to its exact schema token.

Search Document