ocpp/v2_1/enum/notify_ev_charging_needs_status

OCPP 2.1 NotifyEvChargingNeedsStatus enumeration (schema NotifyEVChargingNeedsStatusEnumType).

to_json/decoder map each constructor to/from its exact schema token.

Types

Returns whether the CSMS has been able to process the message successfully. It does not imply that the evChargingNeeds can be met with the current charging profile.

pub type NotifyEvChargingNeedsStatus {
  Accepted
  Rejected
  Processing
  NoChargingProfile
}

Constructors

  • Accepted
  • Rejected
  • Processing
  • NoChargingProfile

Values

pub fn decoder() -> decode.Decoder(NotifyEvChargingNeedsStatus)

Decode a NotifyEvChargingNeedsStatus from its exact schema token.

pub fn to_json(value: NotifyEvChargingNeedsStatus) -> json.Json

Encode a NotifyEvChargingNeedsStatus to its exact schema token.

Search Document