ocpp/v2_1/enum/ocpp_interface
OCPP 2.1 OcppInterface enumeration (schema OCPPInterfaceEnumType).
to_json/decoder map each constructor to/from its exact schema token.
Types
Applicable Network Interface. Charging Station is allowed to use a different network interface to connect if the given one does not work.
pub type OcppInterface {
Wired0
Wired1
Wired2
Wired3
Wireless0
Wireless1
Wireless2
Wireless3
Any
}
Constructors
-
Wired0 -
Wired1 -
Wired2 -
Wired3 -
Wireless0 -
Wireless1 -
Wireless2 -
Wireless3 -
Any
Values
pub fn decoder() -> decode.Decoder(OcppInterface)
Decode a OcppInterface from its exact schema token.
pub fn to_json(value: OcppInterface) -> json.Json
Encode a OcppInterface to its exact schema token.