ocpp/v2_1/enum/phase
OCPP 2.1 Phase enumeration (schema PhaseEnumType).
to_json/decoder map each constructor to/from its exact schema token.
Types
Indicates how the measured value is to be interpreted. For instance between L1 and neutral (L1-N) Please note that not all values of phase are applicable to all Measurands. When phase is absent, the measured value is interpreted as an overall value.
pub type Phase {
L1
L2
L3
N
L1N
L2N
L3N
L1L2
L2L3
L3L1
}
Constructors
-
L1 -
L2 -
L3 -
N -
L1N -
L2N -
L3N -
L1L2 -
L2L3 -
L3L1