ocpp/v2_1/enum/reason
OCPP 2.1 Reason enumeration (schema ReasonEnumType).
to_json/decoder map each constructor to/from its exact schema token.
Types
The stoppedReason is the reason/event that initiated the process of stopping the transaction. It will normally be the user stopping authorization via card (Local or MasterPass) or app (Remote), but it can also be CSMS revoking authorization (DeAuthorized), or disconnecting the EV when TxStopPoint = EVConnected (EVDisconnected). Most other reasons are related to technical faults or energy limitations. + MAY only be omitted when stoppedReason is “Local”
pub type Reason {
DeAuthorized
EmergencyStop
EnergyLimitReached
EvDisconnected
GroundFault
ImmediateReset
MasterPass
Local
LocalOutOfCredit
Other
OvercurrentFault
PowerLoss
PowerQuality
Reboot
Remote
SocLimitReached
StoppedByEv
TimeLimitReached
Timeout
ReqEnergyTransferRejected
}
Constructors
-
DeAuthorized -
EmergencyStop -
EnergyLimitReached -
EvDisconnected -
GroundFault -
ImmediateReset -
MasterPass -
Local -
LocalOutOfCredit -
Other -
OvercurrentFault -
PowerLoss -
PowerQuality -
Reboot -
Remote -
SocLimitReached -
StoppedByEv -
TimeLimitReached -
Timeout -
ReqEnergyTransferRejected