ocpp/v2_1/message/customer_information

OCPP 2.1 CustomerInformation action.

Request/Response payload types with their OCPP-J codecs (request_to_json/request_decoder, response_to_json/ response_decoder). Transport-agnostic; the action-string mapping lives in ocpp/v2_1/dispatch.

Types

FieldTypeReqDescription
clearBoolFlag indicating whether the Charging Station should clear all information about the customer referred to.
custom_dataCustomData
customer_certificateCertificateHashData
customer_identifierStringA (e.g. vendor specific) identifier of the customer this request refers to. This field contains a custom identifier other than IdToken and Certificate. One of the possible identifiers (customerIdentifier, customerIdToken or customerCertificate) should be in the request message. (max 64 chars)
id_tokenIdToken
reportBoolFlag indicating whether the Charging Station should return NotifyCustomerInformationRequest messages containing information about the customer referred to.
request_idIntThe Id of the request. (≥ 0)

Schema: CustomerInformationRequest

pub type Request {
  Request(
    clear: Bool,
    custom_data: option.Option(custom_data.CustomData),
    customer_certificate: option.Option(
      certificate_hash_data.CertificateHashData,
    ),
    customer_identifier: option.Option(String),
    id_token: option.Option(id_token.IdToken),
    report: Bool,
    request_id: Int,
  )
}

Constructors

FieldTypeReqDescription
custom_dataCustomData
statusCustomerInformationStatus
status_infoStatusInfo

Schema: CustomerInformationResponse

pub type Response {
  Response(
    custom_data: option.Option(custom_data.CustomData),
    status: customer_information_status.CustomerInformationStatus,
    status_info: option.Option(status_info.StatusInfo),
  )
}

Constructors

Values

pub fn new_request(
  clear clear: Bool,
  report report: Bool,
  request_id request_id: Int,
) -> Request

Construct a Request from its required fields, with every optional field set to None.

pub fn new_response(
  status status: customer_information_status.CustomerInformationStatus,
) -> Response

Construct a Response from its required fields, with every optional field set to None.

pub fn request_decoder() -> decode.Decoder(Request)

Decode a Request from its OCPP-J JSON object, enforcing schema constraints.

pub fn request_to_json(value: Request) -> json.Json

Encode a Request to its OCPP-J JSON object.

pub fn response_decoder() -> decode.Decoder(Response)

Decode a Response from its OCPP-J JSON object, enforcing schema constraints.

pub fn response_to_json(value: Response) -> json.Json

Encode a Response to its OCPP-J JSON object.

Search Document