ocpp/v2_1/message/get15118_ev_certificate

OCPP 2.1 Get15118EVCertificate action.

Request/Response payload types with their OCPP-J codecs (request_to_json/request_decoder, response_to_json/ response_decoder). Transport-agnostic; the action-string mapping lives in ocpp/v2_1/dispatch.

Types

FieldTypeReqDescription
actionCertificateAction
custom_dataCustomData
exi_requestString(2.1) Raw CertificateInstallationReq request from EV, Base64 encoded. + Extended to support ISO 15118-20 certificates. The minimum supported length is 11000. If a longer exiRequest is supported, then the supported length must be communicated in variable OCPPCommCtrlr.FieldLength[ “Get15118EVCertificateRequest.exiRequest” ]. (max 11000 chars)
iso15118_schema_versionStringSchema version currently used for the 15118 session between EV and Charging Station. Needed for parsing of the EXI stream by the CSMS. (max 50 chars)
maximum_contract_certificate_chainsInt(2.1) Absent during ISO 15118-2 session. Required during ISO 15118-20 session. + Maximum number of contracts that EV wants to install. (≥ 0)
prioritized_emai_dsList(String)(2.1) Absent during ISO 15118-2 session. Optional during ISO 15118-20 session. List of EMAIDs for which contract certificates must be requested first, in case there are more certificates than allowed by maximumContractCertificateChains. (max 255 chars)

Schema: Get15118EVCertificateRequest

pub type Request {
  Request(
    action: certificate_action.CertificateAction,
    custom_data: option.Option(custom_data.CustomData),
    exi_request: String,
    iso15118_schema_version: String,
    maximum_contract_certificate_chains: option.Option(Int),
    prioritized_emai_ds: option.Option(List(String)),
  )
}

Constructors

FieldTypeReqDescription
custom_dataCustomData
exi_responseString(2/1) Raw CertificateInstallationRes response for the EV, Base64 encoded. + Extended to support ISO 15118-20 certificates. The minimum supported length is 17000. If a longer exiResponse is supported, then the supported length must be communicated in variable OCPPCommCtrlr.FieldLength[ “Get15118EVCertificateResponse.exiResponse” ]. (max 17000 chars)
remaining_contractsInt(2.1) Number of contracts that can be retrieved with additional requests. (≥ 0)
statusIso15118EvCertificateStatus
status_infoStatusInfo

Schema: Get15118EVCertificateResponse

pub type Response {
  Response(
    custom_data: option.Option(custom_data.CustomData),
    exi_response: String,
    remaining_contracts: option.Option(Int),
    status: iso15118_ev_certificate_status.Iso15118EvCertificateStatus,
    status_info: option.Option(status_info.StatusInfo),
  )
}

Constructors

Values

pub fn new_request(
  action action: certificate_action.CertificateAction,
  exi_request exi_request: String,
  iso15118_schema_version iso15118_schema_version: String,
) -> Request

Construct a Request from its required fields, with every optional field set to None.

pub fn new_response(
  exi_response exi_response: String,
  status status: iso15118_ev_certificate_status.Iso15118EvCertificateStatus,
) -> Response

Construct a Response from its required fields, with every optional field set to None.

pub fn request_decoder() -> decode.Decoder(Request)

Decode a Request from its OCPP-J JSON object, enforcing schema constraints.

pub fn request_to_json(value: Request) -> json.Json

Encode a Request to its OCPP-J JSON object.

pub fn response_decoder() -> decode.Decoder(Response)

Decode a Response from its OCPP-J JSON object, enforcing schema constraints.

pub fn response_to_json(value: Response) -> json.Json

Encode a Response to its OCPP-J JSON object.

Search Document