ocpp/v2_1/message/publish_firmware

OCPP 2.1 PublishFirmware action.

Request/Response payload types with their OCPP-J codecs (request_to_json/request_decoder, response_to_json/ response_decoder). Transport-agnostic; the action-string mapping lives in ocpp/v2_1/dispatch.

Types

FieldTypeReqDescription
checksumStringThe MD5 checksum over the entire firmware file as a hexadecimal string of length 32. (max 32 chars)
custom_dataCustomData
locationStringThis contains a string containing a URI pointing to a location from which to retrieve the firmware. (max 2000 chars)
request_idIntThe Id of the request. (≥ 0)
retriesIntThis specifies how many times Charging Station must retry to download the firmware before giving up. If this field is not present, it is left to Charging Station to decide how many times it wants to retry. If the value is 0, it means: no retries. (≥ 0)
retry_intervalIntThe interval in seconds after which a retry may be attempted. If this field is not present, it is left to Charging Station to decide how long to wait between attempts. (≥ 0)

Schema: PublishFirmwareRequest

pub type Request {
  Request(
    checksum: String,
    custom_data: option.Option(custom_data.CustomData),
    location: String,
    request_id: Int,
    retries: option.Option(Int),
    retry_interval: option.Option(Int),
  )
}

Constructors

FieldTypeReqDescription
custom_dataCustomData
statusGenericStatus
status_infoStatusInfo

Schema: PublishFirmwareResponse

pub type Response {
  Response(
    custom_data: option.Option(custom_data.CustomData),
    status: generic_status.GenericStatus,
    status_info: option.Option(status_info.StatusInfo),
  )
}

Constructors

Values

pub fn new_request(
  checksum checksum: String,
  location location: String,
  request_id request_id: Int,
) -> Request

Construct a Request from its required fields, with every optional field set to None.

pub fn new_response(
  status status: generic_status.GenericStatus,
) -> Response

Construct a Response from its required fields, with every optional field set to None.

pub fn request_decoder() -> decode.Decoder(Request)

Decode a Request from its OCPP-J JSON object, enforcing schema constraints.

pub fn request_to_json(value: Request) -> json.Json

Encode a Request to its OCPP-J JSON object.

pub fn response_decoder() -> decode.Decoder(Response)

Decode a Response from its OCPP-J JSON object, enforcing schema constraints.

pub fn response_to_json(value: Response) -> json.Json

Encode a Response to its OCPP-J JSON object.

Search Document