ocpp/v2_1/message/set_monitoring_level

OCPP 2.1 SetMonitoringLevel action.

Request/Response payload types with their OCPP-J codecs (request_to_json/request_decoder, response_to_json/ response_decoder). Transport-agnostic; the action-string mapping lives in ocpp/v2_1/dispatch.

Types

FieldTypeReqDescription
custom_dataCustomData
severityIntThe Charging Station SHALL only report events with a severity number lower than or equal to this severity. The severity range is 0-9, with 0 as the highest and 9 as the lowest severity level. The severity levels have the following meaning: + 0-Danger + Indicates lives are potentially in danger. Urgent attention is needed and action should be taken immediately. + 1-Hardware Failure + Indicates that the Charging Station is unable to continue regular operations due to Hardware issues. Action is required. + 2-System Failure + Indicates that the Charging Station is unable to continue regular operations due to software or minor hardware issues. Action is required. + 3-Critical + Indicates a critical error. Action is required. + 4-Error + Indicates a non-urgent error. Action is required. + 5-Alert + Indicates an alert event. Default severity for any type of monitoring event. + 6-Warning + Indicates a warning event. Action may be required. + 7-Notice + Indicates an unusual event. No immediate action is required. + 8-Informational + Indicates a regular operational event. May be used for reporting, measuring throughput, etc. No action is required. + 9-Debug + Indicates information useful to developers for debugging, not useful during operations. (≥ 0)

Schema: SetMonitoringLevelRequest

pub type Request {
  Request(
    custom_data: option.Option(custom_data.CustomData),
    severity: Int,
  )
}

Constructors

FieldTypeReqDescription
custom_dataCustomData
statusGenericStatus
status_infoStatusInfo

Schema: SetMonitoringLevelResponse

pub type Response {
  Response(
    custom_data: option.Option(custom_data.CustomData),
    status: generic_status.GenericStatus,
    status_info: option.Option(status_info.StatusInfo),
  )
}

Constructors

Values

pub fn new_request(severity severity: Int) -> Request

Construct a Request from its required fields, with every optional field set to None.

pub fn new_response(
  status status: generic_status.GenericStatus,
) -> Response

Construct a Response from its required fields, with every optional field set to None.

pub fn request_decoder() -> decode.Decoder(Request)

Decode a Request from its OCPP-J JSON object, enforcing schema constraints.

pub fn request_to_json(value: Request) -> json.Json

Encode a Request to its OCPP-J JSON object.

pub fn response_decoder() -> decode.Decoder(Response)

Decode a Response from its OCPP-J JSON object, enforcing schema constraints.

pub fn response_to_json(value: Response) -> json.Json

Encode a Response to its OCPP-J JSON object.

Search Document