ocpp/v2_0_1/enum/send_local_list_status

OCPP 2.0.1 SendLocalListStatus enumeration (schema SendLocalListStatusEnumType).

to_json/decoder map each constructor to/from its exact schema token.

Types

This indicates whether the Charging Station has successfully received and applied the update of the Local Authorization List.

pub type SendLocalListStatus {
  Accepted
  Failed
  VersionMismatch
}

Constructors

  • Accepted
  • Failed
  • VersionMismatch

Values

pub fn decoder() -> decode.Decoder(SendLocalListStatus)

Decode a SendLocalListStatus from its exact schema token.

pub fn to_json(value: SendLocalListStatus) -> json.Json

Encode a SendLocalListStatus to its exact schema token.

Search Document