ocpp/v2_1/datatype/tariff_conditions_fixed
OCPP 2.1 TariffConditionsFixed data type (schema TariffConditionsFixedType).
to_json/decoder map to/from its OCPP-J JSON object; new (when
present) builds a value from the required fields only.
Types
These conditions describe if a FixedPrice applies at start of the transaction.
When more than one restriction is set, they are to be treated as a logical AND. All need to be valid before this price is active.
NOTE: startTimeOfDay and endTimeOfDay are in local time, because it is the time in the tariff as it is shown to the EV driver at the Charging Station. A Charging Station will convert this to the internal time zone that it uses (which is recommended to be UTC, see section Generic chapter 3.1) when performing cost calculation.
| Field | Type | Req | Description |
|---|---|---|---|
custom_data | CustomData | — | |
day_of_week | List(DayOfWeek) | — | Day(s) of the week this is tariff applies. |
end_time_of_day | String | — | End time of day in local time. Same syntax as startTimeOfDay. + If end time < start time then the period wraps around to the next day. + To stop at end of the day use: 00:00. |
evse_kind | EvseKind | — | |
payment_brand | String | — | For which payment brand this (adhoc) tariff applies. Can be used to add a surcharge for certain payment brands. Based on value of additionalIdToken from idToken.additionalInfo.type = “PaymentBrand”. (max 20 chars) |
payment_recognition | String | — | Type of adhoc payment, e.g. CC, Debit. Based on value of additionalIdToken from idToken.additionalInfo.type = “PaymentRecognition”. (max 20 chars) |
start_time_of_day | String | — | Start time of day in local time. + Format as per RFC 3339: time-hour “:” time-minute + Must be in 24h format with leading zeros. Hour/Minute separator: “:” Regex: ([0-1][0-9]|2[0-3]):[0-5][0-9] |
valid_from_date | String | — | Start date in local time, for example: 2015-12-24. Valid from this day (inclusive). + Format as per RFC 3339: full-date + Regex: ([12][0-9]{3})-(0[1-9]|1[0-2])-(0[1-9]|[12][0-9]|3[01]) |
valid_to_date | String | — | End date in local time, for example: 2015-12-27. Valid until this day (exclusive). Same syntax as validFromDate. |
Schema: TariffConditionsFixedType
pub type TariffConditionsFixed {
TariffConditionsFixed(
custom_data: option.Option(custom_data.CustomData),
day_of_week: option.Option(List(day_of_week.DayOfWeek)),
end_time_of_day: option.Option(String),
evse_kind: option.Option(evse_kind.EvseKind),
payment_brand: option.Option(String),
payment_recognition: option.Option(String),
start_time_of_day: option.Option(String),
valid_from_date: option.Option(String),
valid_to_date: option.Option(String),
)
}
Constructors
-
TariffConditionsFixed( custom_data: option.Option(custom_data.CustomData), day_of_week: option.Option(List(day_of_week.DayOfWeek)), end_time_of_day: option.Option(String), evse_kind: option.Option(evse_kind.EvseKind), payment_brand: option.Option(String), payment_recognition: option.Option(String), start_time_of_day: option.Option(String), valid_from_date: option.Option(String), valid_to_date: option.Option(String), )
Values
pub fn decoder() -> decode.Decoder(TariffConditionsFixed)
Decode a TariffConditionsFixed from its OCPP-J JSON object, enforcing schema constraints.
pub fn new() -> TariffConditionsFixed
Construct a TariffConditionsFixed from its required fields, with every optional field set to None.
pub fn to_json(value: TariffConditionsFixed) -> json.Json
Encode a TariffConditionsFixed to its OCPP-J JSON object.