ocpp/v2_1/enum/ocpp_version
OCPP 2.1 OcppVersion enumeration (schema OCPPVersionEnumType).
to_json/decoder map each constructor to/from its exact schema token.
Types
(2.1) This field is ignored, since the OCPP version to use is determined during the websocket handshake. The field is only kept for backwards compatibility with the OCPP 2.0.1 JSON schema.
pub type OcppVersion {
Ocpp12
Ocpp15
Ocpp16
Ocpp20
Ocpp201
Ocpp21
}
Constructors
-
Ocpp12 -
Ocpp15 -
Ocpp16 -
Ocpp20 -
Ocpp201 -
Ocpp21
Values
pub fn decoder() -> decode.Decoder(OcppVersion)
Decode a OcppVersion from its exact schema token.
pub fn to_json(value: OcppVersion) -> json.Json
Encode a OcppVersion to its exact schema token.